export var GridEntityType;
(function (GridEntityType) {
    GridEntityType[GridEntityType["NULL"] = 0] = "NULL";
    /** Does not correspond to any specific `GridEntity` class. */
    GridEntityType[GridEntityType["DECORATION"] = 1] = "DECORATION";
    /**
     * Grid entities with this type can be converted to the `GridEntityRock` class.
     *
     * Corresponds to `GridEntityXMLType.ROCK` (1000).
     */
    GridEntityType[GridEntityType["ROCK"] = 2] = "ROCK";
    /**
     * Grid entities with this type can be converted to the `GridEntityRock` class.
     *
     * Corresponds to `GridEntityXMLType.BLOCK` (1900).
     */
    GridEntityType[GridEntityType["BLOCK"] = 3] = "BLOCK";
    /**
     * The rocks with an "X" on them that produce soul hearts and other rewards when destroyed.
     *
     * Grid entities with this type can be converted to the `GridEntityRock` class.
     *
     * Corresponds to `GridEntityXMLType.ROCK_TINTED` (1003).
     */
    GridEntityType[GridEntityType["ROCK_TINTED"] = 4] = "ROCK_TINTED";
    /**
     * Grid entities with this type can be converted to the `GridEntityRock` class.
     *
     * Corresponds to `GridEntityXMLType.ROCK_BOMB` (1001).
     */
    GridEntityType[GridEntityType["ROCK_BOMB"] = 5] = "ROCK_BOMB";
    /**
     * An urn, mushroom, skull, polyp, or bucket, depending on what the backdrop type. For more
     * information, see the `getRockAltType` helper function.
     *
     * (Contrary to popular belief, the stage does not matter for the purposes of determining what the
     * `RockAltType` is.)
     *
     * Grid entities with this type can be converted to the `GridEntityRock` class.
     *
     * Corresponds to `GridEntityXMLType.ROCK_ALT` (1002).
     */
    GridEntityType[GridEntityType["ROCK_ALT"] = 6] = "ROCK_ALT";
    /**
     * Grid entities with this type can be converted to the `GridEntityPit` class.
     *
     * Corresponds to `GridEntityXMLType.PIT` (3000).
     */
    GridEntityType[GridEntityType["PIT"] = 7] = "PIT";
    /**
     * Grid entities with this type can be converted to the `GridEntitySpikes` class.
     *
     * Corresponds to `GridEntityXMLType.SPIKES` (1930).
     */
    GridEntityType[GridEntityType["SPIKES"] = 8] = "SPIKES";
    /**
     * Grid entities with this type can be converted to the `GridEntitySpikes` class.
     *
     * Corresponds to `GridEntityXMLType.SPIKES_ON_OFF` (1931).
     */
    GridEntityType[GridEntityType["SPIKES_ON_OFF"] = 9] = "SPIKES_ON_OFF";
    /**
     * Does not correspond to any specific `GridEntity` class.
     *
     * Corresponds to `GridEntityXMLType.SPIDER_WEB` (1940).
     */
    GridEntityType[GridEntityType["SPIDER_WEB"] = 10] = "SPIDER_WEB";
    /**
     * A key block.
     *
     * Does not correspond to any specific `GridEntity` class.
     *
     * Corresponds to `GridEntityXMLType.LOCK` (4000).
     */
    GridEntityType[GridEntityType["LOCK"] = 11] = "LOCK";
    /**
     * Grid entities with this type can be converted to the `GridEntityTNT` class.
     *
     * Corresponds to `GridEntityXMLType.TNT` (1300).
     */
    GridEntityType[GridEntityType["TNT"] = 12] = "TNT";
    /**
     * Does not correspond to any specific `GridEntity` class.
     *
     * Corresponds to `GridEntityXMLType.FIREPLACE` (1400) and `GridEntityXMLType.RED_FIREPLACE`
     * (1410).
     */
    GridEntityType[GridEntityType["FIREPLACE"] = 13] = "FIREPLACE";
    /**
     * Grid entities with this type can be converted to the `GridEntityPoop` class.
     *
     * Corresponds to many different `GridEntityXMLType` values.
     */
    GridEntityType[GridEntityType["POOP"] = 14] = "POOP";
    /**
     * Does not correspond to any specific `GridEntity` class.
     *
     * Corresponds to `GridEntityXMLType.WALL` (1999).
     */
    GridEntityType[GridEntityType["WALL"] = 15] = "WALL";
    /**
     * Grid entities with this type can be converted to the `GridEntityDoor` class.
     *
     * Does not correspond to any `GridEntityXMLType` value.
     */
    GridEntityType[GridEntityType["DOOR"] = 16] = "DOOR";
    /**
     * Does not correspond to any specific `GridEntity` class.
     *
     * Corresponds to `GridEntityXMLType.TRAPDOOR` (9000).
     */
    GridEntityType[GridEntityType["TRAPDOOR"] = 17] = "TRAPDOOR";
    /**
     * Does not correspond to any specific `GridEntity` class.
     *
     * Corresponds to `GridEntityXMLType.CRAWL_SPACE` (9100).
     */
    GridEntityType[GridEntityType["CRAWL_SPACE"] = 18] = "CRAWL_SPACE";
    /**
     * Does not correspond to any specific `GridEntity` class.
     *
     * Corresponds to `GridEntityXMLType.GRAVITY` (10000).
     */
    GridEntityType[GridEntityType["GRAVITY"] = 19] = "GRAVITY";
    /**
     * Grid entities with this type can be converted to the `GridEntityPressurePlate` class.
     *
     * Corresponds to `GridEntityXMLType.PRESSURE_PLATE` (4500).
     */
    GridEntityType[GridEntityType["PRESSURE_PLATE"] = 20] = "PRESSURE_PLATE";
    /**
     * Does not correspond to any specific `GridEntity` class.
     *
     * Corresponds to `GridEntityXMLType.STATUE_DEVIL` (5000) and `GridEntityXMLType.STATUE_ANGEL`
     * (5001).
     */
    GridEntityType[GridEntityType["STATUE"] = 21] = "STATUE";
    /**
     * A super tinted rock that yields double rewards.
     *
     * Grid entities with this type can be converted to the `GridEntityRock` class.
     *
     * Does not correspond to any `GridEntityXMLType` value.
     */
    GridEntityType[GridEntityType["ROCK_SUPER_SPECIAL"] = 22] = "ROCK_SUPER_SPECIAL";
    /**
     * Does not correspond to any specific `GridEntity` class.
     *
     * Corresponds to `GridEntityXMLType.TELEPORTER` (6100).
     */
    GridEntityType[GridEntityType["TELEPORTER"] = 23] = "TELEPORTER";
    /**
     * Grid entities with this type can be converted to the `GridEntityRock` class.
     *
     * Corresponds to `GridEntityXMLType.PILLAR` (1901).
     */
    GridEntityType[GridEntityType["PILLAR"] = 24] = "PILLAR";
    /**
     * Grid entities with this type can be converted to the `GridEntityRock` class.
     *
     * Corresponds to `GridEntityXMLType.ROCK_SPIKED` (1010).
     */
    GridEntityType[GridEntityType["ROCK_SPIKED"] = 25] = "ROCK_SPIKED";
    /**
     * A marked skull that will always drop a Fool card.
     *
     * Grid entities with this type can be converted to the `GridEntityRock` class.
     *
     * Corresponds to `GridEntityXMLType.ROCK_ALT_2` (1008).
     */
    GridEntityType[GridEntityType["ROCK_ALT_2"] = 26] = "ROCK_ALT_2";
    /**
     * Grid entities with this type can be converted to the `GridEntityRock` class.
     *
     * Corresponds to `GridEntityXMLType.ROCK_GOLD` (1011).
     */
    GridEntityType[GridEntityType["ROCK_GOLD"] = 27] = "ROCK_GOLD";
})(GridEntityType || (GridEntityType = {}));
